@@ -293,7 +293,9 @@ def extract_tsx_strings(input_path):
     p = subprocess.Popen(
         cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE, cwd=input_path
     )
-    p.communicate()
+    stderr, stdout = p.communicate()
+    if p.returncode != 0:
+        raise Exception("`gettext-extract` error!")
 
     # Fix the missing format
     with open(output_path, "r") as fh:
